package org.glickr.api.groups.discuss

import org.glickr.api.FlickrApiMethod
import groovy.util.slurpersupport.GPathResult

/* ----------------------------------------------------------------------------------------------------
REQUEST: flickr.groups.discuss.replies.getList
INFO: Get a list of groups.discuss from a group discussion topic.

AUTHENTICATION: This method does not require authentication.

ARGUMENTS:
api_key (Required): Your API application key.
topic_id (Required): The ID of the topic to fetch groups.discuss for.
per_page (Required): Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.
page (Optional): The page of results to return. If this argument is omitted, it defaults to 1.

EXAMPLE RESPONSE:
<rsp stat="ok">
  <groups.discuss>
    <topic topic_id="72157625038324579" subject="A long time ago in a galaxy far, far away..." group_id="46744914@N00" iconserver="1" iconfarm="1" name="Tell a story in 5 frames (Visual story telling)" author="53930889@N04" authorname="Smallportfolio_jm08" role="member" author_iconserver="5169" author_iconfarm="6" can_edit="0" can_delete="0" can_reply="0" is_sticky="0" is_locked="" datecreate="2010-10-14T08:42:45-07:00" datelastpost="2012-05-13T03:38:38-07:00" total="8" page="1" per_page="3" pages="2">
        <message>&amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5080874079/&amp;quot; title=&amp;quot;Star Wars 1 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4035/5080874079_684cf874e0_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 1 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
        &amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467846/&amp;quot; title=&amp;quot;Star Wars 2 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4071/5081467846_2eec86176d_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 2 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
        &amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467886/&amp;quot; title=&amp;quot;Star Wars 3 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4021/5081467886_d8cca6c8e8_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 3 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
        &amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467910/&amp;quot; title=&amp;quot;Star Wars 4 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4084/5081467910_274bb11fdc_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 4 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
        &amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467948/&amp;quot; title=&amp;quot;Star Wars 5 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4154/5081467948_1a5f200bc0_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 5 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;</message>
    </topic>
    <reply id="72157625163054214" author="41380738@N05" authorname="BlueRidgeKitties" role="member" iconserver="2459" iconfarm="3" can_edit="0" can_delete="0" datecreate="2010-10-14T08:52:19-07:00" lastedit="0">
        <message>*LOL* The universe is full of &amp;lt;a href=&amp;quot;http://www.flickr.com/groups/visualstory/discuss/72157622533160886/&amp;quot;&amp;gt;giant furry space monsters&amp;lt;/a&amp;gt; it seems! Love it.</message>
    </reply>
    <reply id="72157625163539300" author="52101018@N00" authorname="pterandon" role="admin" iconserver="1" iconfarm="1" can_edit="0" can_delete="0" datecreate="2010-10-14T10:19:08-07:00" lastedit="0">
        <message>Great work. Good focus on different aspects of scene in each frame.  Funny ending-- even better that I didn't notice the cat right away!  Being a hopeless Trekkie, I was wondering why Han was doing the Vulcan death grip on one of his allies....</message>
    </reply>
    <reply id="72157625040116805" author="54830408@N02" authorname="tay.grisham" role="member" iconserver="0" iconfarm="0" can_edit="0" can_delete="0" datecreate="2010-10-14T13:57:38-07:00" lastedit="0">
        <message>On a scale of 1 to 10 of awesome. This is a 15</message>
    </reply>
  </groups.discuss>
</rsp>
---------------------------------------------------------------------------------------------------- */

class discussRepliesGetList implements FlickrApiMethod {
    //
    //  API METHOD
    //
    static final String apiMethod = 'flickr.groups.discuss.replies.getList'

    //
    //  VALIDATOR
    //

    //
    //  PARAMS
    //

    //
    //  PROCESSOR
    //

    //
    //  ERROR CODES
    //
}