package org.glickr.api.groups.discuss

import org.glickr.api.FlickrApiMethod
import groovy.util.slurpersupport.GPathResult

/* ----------------------------------------------------------------------------------------------------
REQUEST: flickr.groups.discuss.topics.getList
INFO: Get a list of discussion topics in a group.

AUTHENTICATION: This method does not require authentication.

ARGUMENTS:
api_key (Required): Your API application key.
group_id (Required): The NSID of the group to fetch information for.
per_page (Optional): Number of photos to return per page. If this argument is omitted, it defaults to 100. The maximum allowed value is 500.
page (Optional): The page of results to return. If this argument is omitted, it defaults to 1.

EXAMPLE RESPONSE:
<rsp stat="ok">
  <topics group_id="46744914@N00" iconserver="1" iconfarm="1" name="Tell a story in 5 frames (Visual story telling)" members="12428" privacy="3" lang="en-us" ispoolmoderated="1" total="4621" page="1" per_page="2" pages="2310">
    <topic id="72157625038324579" subject="A long time ago in a galaxy far, far away..." author="53930889@N04" authorname="Smallportfolio_jm08" role="member" iconserver="5169" iconfarm="6" count_replies="8" can_edit="0" can_delete="0" can_reply="0" is_sticky="0" is_locked="" datecreate="2010-10-14T08:42:45-07:00" datelastpost="2012-05-13T03:38:38-07:00">
<message>&amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5080874079/&amp;quot; title=&amp;quot;Star Wars 1 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4035/5080874079_684cf874e0_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 1 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
&amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467846/&amp;quot; title=&amp;quot;Star Wars 2 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4071/5081467846_2eec86176d_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 2 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
&amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467886/&amp;quot; title=&amp;quot;Star Wars 3 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4021/5081467886_d8cca6c8e8_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 3 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
&amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467910/&amp;quot; title=&amp;quot;Star Wars 4 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4084/5081467910_274bb11fdc_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 4 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;
&amp;lt;div&amp;gt;&amp;lt;span class=&amp;quot;photo_container pc_m bbml_img&amp;quot;&amp;gt;&amp;lt;a href=&amp;quot;/photos/53930889@N04/5081467948/&amp;quot; title=&amp;quot;Star Wars 5 by Smallportfolio_jm08&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm5.staticflickr.com/4154/5081467948_1a5f200bc0_m.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;180&amp;quot; alt=&amp;quot;Star Wars 5 by Smallportfolio_jm08&amp;quot;  class=&amp;quot;pc_img&amp;quot; border=&amp;quot;0&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;&amp;lt;/span&amp;gt;&amp;lt;/div&amp;gt;</message>
    </topic>
    <topic id="72157629635119774" subject="Where The Fish Are" author="75240402@N04" authorname="Nokinrocks" role="member" iconserver="7027" iconfarm="8" count_replies="0" can_edit="0" can_delete="0" can_reply="0" is_sticky="0" is_locked="" datecreate="2012-05-08T07:00:53-07:00" datelastpost="2012-05-08T07:00:53-07:00">
<message>&amp;lt;a href=&amp;quot;http://www.flickr.com/photos/nokinrocks/7120495637/&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm9.staticflickr.com/8005/7120495637_fec0382b4b_n.jpg&amp;quot; width=&amp;quot;320&amp;quot; height=&amp;quot;256&amp;quot; alt=&amp;quot;Step It Up&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;
&amp;lt;a href=&amp;quot;http://www.flickr.com/photos/nokinrocks/7122908705/&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm8.staticflickr.com/7259/7122908705_3bef338378_n.jpg&amp;quot; width=&amp;quot;240&amp;quot; height=&amp;quot;320&amp;quot; alt=&amp;quot;P1050351&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;
&amp;lt;a href=&amp;quot;http://www.flickr.com/photos/nokinrocks/7122922123/&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm8.staticflickr.com/7052/7122922123_2bfcb6707c_n.jpg&amp;quot; width=&amp;quot;214&amp;quot; height=&amp;quot;320&amp;quot; alt=&amp;quot;Frog On A Log&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;
&amp;lt;a href=&amp;quot;http://www.flickr.com/photos/nokinrocks/7122929521/&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm8.staticflickr.com/7047/7122929521_8ffebdd424_n.jpg&amp;quot; width=&amp;quot;320&amp;quot; height=&amp;quot;200&amp;quot; alt=&amp;quot;P1050397&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;
&amp;lt;a href=&amp;quot;http://www.flickr.com/photos/nokinrocks/7122916999/&amp;quot;&amp;gt;&amp;lt;img class=&amp;quot;notsowide&amp;quot; src=&amp;quot;http://farm8.staticflickr.com/7200/7122916999_a7328f9dcc_n.jpg&amp;quot; width=&amp;quot;320&amp;quot; height=&amp;quot;261&amp;quot; alt=&amp;quot;P1050361&amp;quot; /&amp;gt;&amp;lt;/a&amp;gt;</message>
    </topic>
  </topics>
</rsp>
---------------------------------------------------------------------------------------------------- */

class discussTopicsGetList implements FlickrApiMethod {
    //
    //  API METHOD
    //
    static final String apiMethod = 'flickr.groups.discuss.topics.getList'

    //
    //  VALIDATOR
    //

    //
    //  PARAMS
    //

    //
    //  PROCESSOR
    //

    //
    //  ERROR CODES
    //
}