package org.glickr.api.people

import org.glickr.api.FlickrApiMethod
import org.glickr.FlickrPeople
import groovy.util.slurpersupport.GPathResult
import org.glickr.FlickrServiceApiException
import org.glickr.FlickrServicePluginException

/* ----------------------------------------------------------------------------------------------------
REQUEST: flickr.people.findByUsername
INFO: Return a user's NSID, given their username.

AUTHENTICATION: This method does not require authentication.

ARGUMENTS:
api_key (Required): Your API application key.
username (Required): The username of the user to lookup.

EXAMPLE RESPONSE:
<user nsid="12037949632@N01">
  <username>Stewart</username>
</user>
---------------------------------------------------------------------------------------------------- */

class peopleFindByUsername implements FlickrApiMethod {
    //
    //  API METHOD
    //
    static final String apiMethod = 'flickr.people.findByUsername'

    //
    //  VALIDATOR
    //
    def validatorClosure = { FlickrPeople people ->
        if (!people || !people?.username) { return [validated:false, message:"Required parameter 'FlickrPeople.username' is missing"] }
        return [validated:true]
    }

    //
    //  PARAMS
    //
    def paramsClosure = { FlickrPeople people ->
        [username:people?.username]
    }

    //
    //  PROCESSOR
    //
    Closure processorClosure = { GPathResult response, FlickrPeople people ->
        people.id       = response.user.@id.toString()
        people.nsid     = response.user.@nsid.toString()
        people.username = response.user.username.toString()
        return people
    }

    //
    //  ERROR CODES
    //
    Closure errorsClosure = { GPathResult response ->
        if (response.err.@code.toInteger() == 1) { return null }      // user not found

        // recoverable errors
        if ([100,105,116].contains(response.err.@code.toInteger())) {
            return new FlickrServiceApiException(response)
        } else {
            return new FlickrServicePluginException(response)
        }
    }
}
